@@ -32,7 +32,7 @@ ivo_excl_missing <- function(df, exclude_missing = FALSE, missing_string = "(Mis
         df[[i]] <- as.character(df[[i]])
         df[is.na(df[[i]]),i] <- "6049122418972891471204127890512XY"
         df[[i]] <- factor(df[[i]], levels = c(levs, "6049122418972891471204127890512XY"), labels = c(levs, missing_string))
-      } else if(sum(is.na(df[[i]]))>0) { df[is.na(df[[i]]), i] <- missing_string }
+      } else if(sum(is.na(df[[i]]))>0) { df[[i]][is.na(df[[i]])] <- missing_string }
     }} else {
       df <- stats::na.omit(df)
     }
@@ -128,11 +128,8 @@ ivo_tab3_step1 <- function(df, v1, v3, v4, exclude_missing, missing_string)
   df |> dplyr::select({{v4}}, {{v1}}, {{v3}}) |>
     ivo_excl_missing(exclude_missing, missing_string) |>
     stats::ftable(exclude=NULL) |>
-    base::data.frame() #|>
-    # `colnames<-`(c({{v1}}, {{v3}}, {{v4}}, "Freq")) -> df
-    # df[order(df[,1]),]
-    #`colnames<-`(c({{v1}}, {{v3}}, {{v4}}, "Freq")) |>
-    #dplyr::arrange(.data[[v4]])
+    base::data.frame() |>
+    `colnames<-`(c({{v1}}, {{v3}}, {{v4}}, "Freq"))
 }
 
 ivo_tab3_step2 <- function(df, v1, v3, v4, extra_header, colsums, rowsums, percent_by, remove_zero_rows, sums_string)
@@ -185,10 +182,9 @@ ivo_tab4_step1 <- function(df, v1, v2, v3, v4, exclude_missing, missing_string)
   df |> dplyr::select({{v4}}, {{v1}}, {{v2}}, {{v3}}) |>
     ivo_excl_missing(exclude_missing, missing_string) |>
     stats::ftable(exclude=NULL) |>
-    base::data.frame() #|>
-    #`colnames<-`(c({{v1}}, {{v2}}, {{v3}}, {{v4}}, "Freq"))
-  # -> df
-  #   df[do.call(order, list(df[,1], df[,2])),]
+    base::data.frame() |>
+    `colnames<-`(c({{v1}}, {{v2}}, {{v3}}, {{v4}}, "Freq"))
+
 }
 
 ivo_tab4_step2 <- function(df, v1, v2, v3, v4, extra_header, colsums, rowsums, percent_by, remove_zero_rows, sums_string)
